" Vim filetype plugin file
" Language:	Luau
" Maintainer:	None yet
" Last Change:	2023 Apr 30

if exists("b:did_ftplugin")
  finish
endif

" Luau is a superset of Lua
runtime! ftplugin/lua.vim


" vim: nowrap sw=2 sts=2 ts=8
